---
name: v.in.lines.py
description: Imports ASCII x,y[,z] coordinates as a series of lines.
keywords: [ vector, import, line, point ]
---

# v.in.lines.py

Imports ASCII x,y[,z] coordinates as a series of lines.

=== "Command line"

    **v.in.lines.py**
    [**-z**]
    **input**=*name*
    **output**=*name*
    [**separator**=*character*]
    [**--overwrite**]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    v.in.lines.py input=name output=name
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***v.in.lines.py***",
        **input**,
        **output**,
        **separator**=*"pipe"*,
        **flags**=*None*,
        **overwrite**=*False*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("v.in.lines.py", input="name", output="name")
    ```

## Parameters

=== "Command line"

    **input**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input file (or "-" to read from stdin)  
    **output**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
    **separator**=*character*  
    &nbsp;&nbsp;&nbsp;&nbsp;Field separator  
    &nbsp;&nbsp;&nbsp;&nbsp;Special characters: pipe, comma, space, tab, newline  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *pipe*  
    **-z**  
    &nbsp;&nbsp;&nbsp;&nbsp;Create a 3D line from 3 column data  
    **--overwrite**  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **input** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input file (or "-" to read from stdin)  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, file, *name*  
    **output** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: output, vector, *name*  
    **separator** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Field separator  
    &nbsp;&nbsp;&nbsp;&nbsp;Special characters: pipe, comma, space, tab, newline  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, separator, *character*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *pipe*  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *z*  
    &nbsp;&nbsp;&nbsp;&nbsp;**z**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Create a 3D line from 3 column data  
    **overwrite**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

Imports a stream of ASCII x,y\[,z\] coordinates as a line or series of
lines.

## NOTES

Input ASCII coordinates are simply a series of "x y" data points. Lines
are separated by a row containing "`NaN NaN`".

The user can import 3D lines by providing 3 columns of data in the input
stream and using the **-z** flag.

This script is a simple wrapper around the *v.in.mapgen* module.

## EXAMPLE

```sh
v.in.lines in=- out=two_lines separator=, <<EOF
167.846717,-46.516653
167.846663,-46.516645
167.846656,-46.516644
167.846649,-46.516644
167.846642,-46.516643
NaN,NaN
167.846520,-46.516457
167.846528,-46.516461
167.846537,-46.516464
167.846535,-46.516486
167.846544,-46.516489
167.846552,-46.516493
EOF
```

## SEE ALSO

*[d.graph](d.graph.md), [v.centroids](v.centroids.md),
[v.in.ascii](v.in.ascii.md), [v.in.mapgen](v.in.mapgen.md),
[v.in.region](v.in.region.md), [v.out.ascii](v.out.ascii.md),
[r.in.poly](r.in.poly.md)*

## AUTHOR

Hamish Bowman  
Dunedin, New Zealand

## SOURCE CODE

Available at: [v.in.lines source code](https://github.com/OSGeo/grass/tree/main/scripts/v.in.lines)
([history](https://github.com/OSGeo/grass/commits/main/scripts/v.in.lines))  
Latest change: Wednesday Mar 05 14:10:57 2025 in commit [8605efe](https://github.com/OSGeo/grass/commit/8605efeb76f1112df8cc657220ce4e1f1c1b94f3)
